Package 'simExam'
| Title: |
Generate Simulated Data for IRT-Enabled Exams |
| Description: |
Generates binary test data based on Item Response Theory
using the two-parameter logistic model (Lord, 1980
<doi:10.4324/9780203056615>). Useful functions for test
equating are included, e.g. functions for generating internal
and external common items between test forms and a function to
create a linkage plans between those forms. Ancillary functions
for generating true item and person parameters as well as for
calculating the probability of a person correctly answering an
item are also included. |
| Authors: |
Waldir Leoncio <[email protected]> |
| Maintainer: |
Waldir Leoncio <[email protected]> |
| License: |
GPL-3 |
| Version: |
1.0.0 |
| Built: |
2026-05-13 06:04:11 UTC |
| Source: |
https://github.com/wleoncio/simexam |
Help Index